clients

package
v1.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 11, 2026 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ClassicClient

type ClassicClient struct {
	Port   string
	Client *dns.Client
}

func (*ClassicClient) ExchangeContext

func (client *ClassicClient) ExchangeContext(ctx context.Context, msg *dns.Msg, ip string) (*dns.Msg, time.Duration, error)

type DOQClient

type DOQClient struct {
	Port      string
	TLSConfig *tls.Config
	Timeout   time.Duration
}

DOQClient represents the config options for setting up a DOQ based client.

func (*DOQClient) ExchangeContext

func (c *DOQClient) ExchangeContext(ctx context.Context, msg *dns.Msg, addr string) (rsp *dns.Msg, rtt time.Duration, err error)

ExchangeContext sends msg to the address specified in addr (without port number).

Jump to